@@ -1,3 +1,11 @@
+class SchedulerError(Exception):
+    """Generic class for catching all exceptions
+    that are not defined here
+    """
+
+    pass
+
+
 class InputUriError(Exception):
     def __init__(self, input_uri: str):
         self.input_uri = input_uri
