@@ -1,4 +1,4 @@
-import React, { useState } from 'react';
+import React, { useCallback, useState } from 'react';
 
 import { JupyterFrontEnd } from '@jupyterlab/application';
 
@@ -65,6 +65,31 @@ export function JobDetail(props: IJobDetailProps): JSX.Element {
 
   const ss = new SchedulerService({});
 
+  const translateStatus = useCallback(
+    (status: Scheduler.Status) => {
+      // This may look inefficient, but it's intended to call the `trans` function
+      // with distinct, static values, so that code analyzers can pick up all the
+      // needed source strings.
+      switch (status) {
+        case 'CREATED':
+          return trans.__('Created');
+        case 'QUEUED':
+          return trans.__('Queued');
+        case 'COMPLETED':
+          return trans.__('Completed');
+        case 'FAILED':
+          return trans.__('Failed');
+        case 'IN_PROGRESS':
+          return trans.__('In progress');
+        case 'STOPPED':
+          return trans.__('Stopped');
+        case 'STOPPING':
+          return trans.__('Stopping');
+      }
+    },
+    [trans]
+  );
+
   const handleDeleteJob = async () => {
     await ss.deleteJob(props.model.jobId ?? '');
     props.setJobsView(JobsView.ListJobs);
@@ -90,15 +115,17 @@ export function JobDetail(props: IJobDetailProps): JSX.Element {
 
   const ButtonBar = (
     <Stack direction="row" gap={2} justifyContent="flex-end" flexWrap={'wrap'}>
-      {props.model.downloaded === false && props.model.status === 'COMPLETED' && (
-        <Button
-          variant="outlined"
-          onClick={downloadFiles}
-          disabled={downloading}
-        >
-          {trans.__('Download Job Files')}
-        </Button>
-      )}
+      {props.model.downloaded === false &&
+        (props.model.status === 'COMPLETED' ||
+          props.model.status === 'FAILED') && (
+          <Button
+            variant="outlined"
+            onClick={downloadFiles}
+            disabled={downloading}
+          >
+            {trans.__('Download Job Files')}
+          </Button>
+        )}
       {props.model.status === 'IN_PROGRESS' && (
         <ConfirmDialogStopButton
           handleStop={handleStopJob}
@@ -114,6 +141,10 @@ export function JobDetail(props: IJobDetailProps): JSX.Element {
     </Stack>
   );
 
+  const inputJobFile = props.model.job_files.find(
+    jobFile => jobFile.file_format === 'input' && jobFile.file_path
+  );
+
   const coreOptionsFields: ILabeledValueProps[][] = [
     [
       { value: props.model.jobName, label: trans.__('Job name') },
@@ -121,8 +152,14 @@ export function JobDetail(props: IJobDetailProps): JSX.Element {
     ],
     [
       {
-        value: props.model.inputFile,
-        label: trans.__('Input filename')
+        label: trans.__('Input file'),
+        value: inputJobFile ? (
+          <JobFileLink app={props.app} jobFile={inputJobFile}>
+            {props.model.inputFile}
+          </JobFileLink>
+        ) : (
+          props.model.inputFile
+        )
       },
       {
         value: props.model.environment,
@@ -130,7 +167,10 @@ export function JobDetail(props: IJobDetailProps): JSX.Element {
       }
     ],
     [
-      { value: props.model.status ?? '', label: trans.__('Status') },
+      {
+        value: translateStatus(props.model.status!),
+        label: trans.__('Status')
+      },
       {
         value: timestampLocalize(props.model.createTime ?? ''),
         label: trans.__('Created at')
@@ -154,13 +194,11 @@ export function JobDetail(props: IJobDetailProps): JSX.Element {
     ]
   ];
 
-  const convertJsonToJobFile = (jobFile: { [key: string]: string }) => {
-    return {
-      display_name: jobFile['display_name'],
-      file_format: jobFile['file_format'],
-      file_path: jobFile['file_path'] || null
-    } as Scheduler.IJobFile;
-  };
+  const hasOutputs =
+    (props.model.status === 'COMPLETED' || props.model.status === 'FAILED') &&
+    props.model.job_files.some(
+      jobFile => jobFile.file_format !== 'input' && jobFile.file_path
+    );
 
   const CoreOptions = (
     <Card>
@@ -178,18 +216,19 @@ export function JobDetail(props: IJobDetailProps): JSX.Element {
               ))}
             </Stack>
           ))}
-          {props.model.status === 'COMPLETED' && (
+          {hasOutputs && (
             <>
-              <FormLabel component="legend">{trans.__('Job files')}</FormLabel>
-              {props.model.job_files.map(
-                jobFile =>
-                  jobFile['file_path'] && (
-                    <JobFileLink
-                      jobFile={convertJsonToJobFile(jobFile)}
-                      app={props.app}
-                    />
-                  )
-              )}
+              <FormLabel component="legend">
+                {trans.__('Output files')}
+              </FormLabel>
+              {props.model.job_files
+                .filter(
+                  jobFile =>
+                    jobFile.file_format !== 'input' && jobFile.file_path
+                )
+                .map(jobFile => (
+                  <JobFileLink jobFile={jobFile} app={props.app} />
+                ))}
             </>
           )}
         </Stack>
